summaryrefslogtreecommitdiffstats
path: root/core/subsurface-qt/DiveListNotifier.h
diff options
context:
space:
mode:
Diffstat (limited to 'core/subsurface-qt/DiveListNotifier.h')
-rw-r--r--core/subsurface-qt/DiveListNotifier.h9
1 files changed, 8 insertions, 1 deletions
diff --git a/core/subsurface-qt/DiveListNotifier.h b/core/subsurface-qt/DiveListNotifier.h
index 46e160208..b57595aa6 100644
--- a/core/subsurface-qt/DiveListNotifier.h
+++ b/core/subsurface-qt/DiveListNotifier.h
@@ -10,7 +10,7 @@
#include <QObject>
// Dive fields that can be edited.
// Use "enum class" to not polute the global name space.
enum class DiveField {
NR,
@@ -29,6 +29,10 @@ enum class DiveField {
MODE,
NOTES,
};
+enum class TripField {
+ LOCATION,
+ NOTES
+};
class DiveListNotifier : public QObject {
Q_OBJECT
@@ -54,6 +58,9 @@ signals:
void cylindersReset(dive_trip *trip, const QVector<dive *> &dives);
void weightsystemsReset(dive_trip *trip, const QVector<dive *> &dives);
+ // Trip edited signal
+ void tripChanged(dive_trip *trip, TripField field);
+
// Selection-signals come in two kinds:
// - divesSelected, divesDeselected and currentDiveChanged are finer grained and are
// called batch-wise per trip (except currentDiveChanged, of course). These signals
@@ -10,7 +10,7 @@
#include <QObject>
-// Dive fields that can be edited.
+// Dive and trip fields that can be edited.
// Use "enum class" to not polute the global name space.
enum class DiveField {